package envoy.client;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.ArrayList;
import java.util.List;

import envoy.exception.EnvoyException;
import envoy.schema.User;

/**
 * Project: <strong>envoy-client</strong><br>
 * File: <strong>LocalDB.java</strong><br>
 * Created: <strong>27.10.2019</strong><br>
 *
 * @author Kai S. K. Engelbart
 * @since Envoy v0.1-alpha
 */
public class LocalDB {

	private File		localDB;
	private User		sender;
	private List<Chat>	chats	= new ArrayList<>();

	public LocalDB(User sender) { this.sender = sender; }

	public void initializeDBFile(File localDBDir) throws EnvoyException {
		if (localDBDir.exists() && !localDBDir.isDirectory())
			throw new EnvoyException(String.format("LocalDBDir '%s' is not a directory!", localDBDir.getAbsolutePath()));
		localDB = new File(localDBDir, sender.getID() + ".db");
		if (localDB.exists()) loadFromLocalDB();
	}

	public void saveToLocalDB() {
		try {
			localDB.getParentFile().mkdirs();
			localDB.createNewFile();
		} catch (IOException e) {
			e.printStackTrace();
		}
		try (ObjectOutputStream out = new ObjectOutputStream(new FileOutputStream(localDB))) {
			out.writeObject(chats);
		} catch (IOException ex) {
			ex.printStackTrace();
		}
	}

	@SuppressWarnings("unchecked")
	private void loadFromLocalDB() throws EnvoyException {
		try (ObjectInputStream in = new ObjectInputStream(new FileInputStream(localDB))) {
			Object obj = in.readObject();
			if (obj instanceof ArrayList<?>) chats = (ArrayList<Chat>) obj;
		} catch (ClassNotFoundException | IOException e) {
			throw new EnvoyException(e);
		}
	}

	public List<Chat> getChats() { return chats; }
}
